@@ -232,11 +232,11 @@ class Window(hildon.StackableWindow):
     show_pointer = None
     pannable_area = None
 
-    def __init__(self, url, id):
+    def __init__(self, url, id, dt):
         gtk.Window.__init__(self)        
         self.connect("delete_event", self.close_window)
         self.url = url
-        self.theatreid = id
+        self.theatreid = id.rstrip()
         self.showtime = []
         self.originalname = []
         self.auditorium = []
@@ -247,6 +247,9 @@ class Window(hildon.StackableWindow):
         self.exiting = False
         self.scheduledate = ''
         
+        #Showing window
+        self.show_all()
+
         #Make pannable area with vbox (we add later hbox into it)
         self.vbox = gtk.VBox()
         global pannable_area
@@ -254,13 +257,12 @@ class Window(hildon.StackableWindow):
         pannable_area.add_with_viewport(self.vbox)
         pannable_area.connect_after('map', self.show_scroll)
         self.add(pannable_area)
-        #Showing window
-        self.show_all()
                 
         #set hourglass running
         hildon.hildon_gtk_window_set_progress_indicator(self, 1) 
         #Start get schedule thread
-        target = '%sschedule/?theatreId=%s' % (self.url, self.theatreid)
+        target = '%sschedule/?theatreId=%s&date=%s' % (self.url, self.theatreid, dt)
+        #print target
         self.bthread = threading.Thread(target=self.do_all, args=(target,))
         self.bthread.start()
         #create rating thread so we can stop it when exiting 
@@ -352,6 +354,7 @@ class Window(hildon.StackableWindow):
         butt_header.set_text("Schedule for date " + self.scheduledate + " (fetched: " + time.strftime("%a, %d %b %Y %H:%M:%S", time.localtime()) + ")", "Press here for scrolling to current time")
         butt_header.set_value_alignment(.5, 1)
         butt_header.connect("clicked", self.show_scroll)
+        show_pointer = butt_header
         self.vbox.pack_start(butt_header)
         
         for index, item in enumerate(self.originalname):
@@ -489,6 +492,7 @@ class MainWindow(hildon.StackableWindow):
         self.sitenames = ['Forum Cinema Estonia', 'Forum Cinema Latvia', 'Forum Cinema Lithuania', 'Finnkino Finland']
         self.defaultsite = 0
         self.currentsite = 0
+        self.currentdate = time.strftime("%Y-%M-%D", time.localtime())
         self.read_config()
         
         #Make pannable area with vbox (we add later buttons into it)
@@ -580,16 +584,30 @@ class MainWindow(hildon.StackableWindow):
         gtk.Dialog.run(note)
         			
     def butt_cinema_click(self, button, index):        
-        self.win = Window(self.sites[self.defaultsite], self.cinemas[0][index])
+        self.win = Window(self.sites[self.defaultsite], self.cinemas[0][index], self.currentdate)
         self.win.set_title(self.cinemas[1][index])
         #Create a banner with a markup
         banner = hildon.hildon_banner_show_information(self.win, "None", "Downloading schedule")
+
+    def date_changed(self, button):
+        sel_dt = button.get_date()
+        #print sel_dt
+        #month is starting from 0 so we add 1 (very strange)
+        self.currentdate = ("%d-%d-%d" % (sel_dt[0], sel_dt[1]+1, sel_dt[2]))
+        #print self.currentdate
+
+    def add_date_button(self):
+        btn_date = hildon.DateButton(gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_HORIZONTAL)
+        btn_date.set_title("Change Date:")
+        btn_date.connect("value-changed", self.date_changed)
+        self.vbox.pack_start(btn_date, False) 
 	
     def download_cinemas_list(self, *args):
         #Clear previous buttons and list
         for item in self.vbox:
             self.vbox.remove(item)
-        del self.cinemas[0:len(self.cinemas)]        
+        del self.cinemas[0:len(self.cinemas)]  
+        self.add_date_button()      
         try:
             id = []
             name = []
